Welcome to the |project| documentation!
=======================================

.. include:: ../README.rst
   :start-line: 26
   :end-line: 41

You can find the source code on `Github <https://github.com/pupil-labs/pye3d-detector/>`_.

If you want to install a modified version of the source code, you will have to install
the platform-specific dependencies first. For details, see :ref:`install_from_source`.


Table of Contents
-----------------

.. toctree::
   :maxdepth: 1

   install_from_source
   examples
   history


Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
